diff mpeg.c @ 1167:d89d7ef290da libavformat

give AVInput/OutputFormat structs consistent names
author mru
date Sun, 09 Jul 2006 23:40:53 +0000
parents 11a8f0c50814
children d18cc9a1fd02
line wrap: on
line diff
--- a/mpeg.c	Sun Jul 09 10:33:49 2006 +0000
+++ b/mpeg.c	Sun Jul 09 23:40:53 2006 +0000
@@ -108,11 +108,11 @@
 static const int lpcm_freq_tab[4] = { 48000, 96000, 44100, 32000 };
 
 #ifdef CONFIG_MUXERS
-static AVOutputFormat mpeg1system_mux;
-static AVOutputFormat mpeg1vcd_mux;
-static AVOutputFormat mpeg2vob_mux;
-static AVOutputFormat mpeg2svcd_mux;
-static AVOutputFormat mpeg2dvd_mux;
+static AVOutputFormat mpeg1system_muxer;
+static AVOutputFormat mpeg1vcd_muxer;
+static AVOutputFormat mpeg2vob_muxer;
+static AVOutputFormat mpeg2svcd_muxer;
+static AVOutputFormat mpeg2dvd_muxer;
 
 static int put_pack_header(AVFormatContext *ctx,
                            uint8_t *buf, int64_t timestamp)
@@ -330,10 +330,10 @@
     int video_bitrate;
 
     s->packet_number = 0;
-    s->is_vcd = (ctx->oformat == &mpeg1vcd_mux);
-    s->is_svcd = (ctx->oformat == &mpeg2svcd_mux);
-    s->is_mpeg2 = (ctx->oformat == &mpeg2vob_mux || ctx->oformat == &mpeg2svcd_mux || ctx->oformat == &mpeg2dvd_mux);
-    s->is_dvd = (ctx->oformat == &mpeg2dvd_mux);
+    s->is_vcd = (ctx->oformat == &mpeg1vcd_muxer);
+    s->is_svcd = (ctx->oformat == &mpeg2svcd_muxer);
+    s->is_mpeg2 = (ctx->oformat == &mpeg2vob_muxer || ctx->oformat == &mpeg2svcd_muxer || ctx->oformat == &mpeg2dvd_muxer);
+    s->is_dvd = (ctx->oformat == &mpeg2dvd_muxer);
 
     if(ctx->packet_size)
         s->packet_size = ctx->packet_size;
@@ -1713,7 +1713,7 @@
 }
 
 #ifdef CONFIG_MUXERS
-static AVOutputFormat mpeg1system_mux = {
+static AVOutputFormat mpeg1system_muxer = {
     "mpeg",
     "MPEG1 System format",
     "video/mpeg",
@@ -1726,7 +1726,7 @@
     mpeg_mux_end,
 };
 
-static AVOutputFormat mpeg1vcd_mux = {
+static AVOutputFormat mpeg1vcd_muxer = {
     "vcd",
     "MPEG1 System format (VCD)",
     "video/mpeg",
@@ -1739,7 +1739,7 @@
     mpeg_mux_end,
 };
 
-static AVOutputFormat mpeg2vob_mux = {
+static AVOutputFormat mpeg2vob_muxer = {
     "vob",
     "MPEG2 PS format (VOB)",
     "video/mpeg",
@@ -1752,8 +1752,8 @@
     mpeg_mux_end,
 };
 
-/* Same as mpeg2vob_mux except that the pack size is 2324 */
-static AVOutputFormat mpeg2svcd_mux = {
+/* Same as mpeg2vob_muxer except that the pack size is 2324 */
+static AVOutputFormat mpeg2svcd_muxer = {
     "svcd",
     "MPEG2 PS format (VOB)",
     "video/mpeg",
@@ -1766,8 +1766,8 @@
     mpeg_mux_end,
 };
 
-/*  Same as mpeg2vob_mux except the 'is_dvd' flag is set to produce NAV pkts */
-static AVOutputFormat mpeg2dvd_mux = {
+/*  Same as mpeg2vob_muxer except the 'is_dvd' flag is set to produce NAV pkts */
+static AVOutputFormat mpeg2dvd_muxer = {
     "dvd",
     "MPEG2 PS format (DVD VOB)",
     "video/mpeg",
@@ -1782,7 +1782,7 @@
 
 #endif //CONFIG_MUXERS
 
-AVInputFormat mpegps_demux = {
+AVInputFormat mpegps_demuxer = {
     "mpeg",
     "MPEG PS format",
     sizeof(MpegDemuxContext),
@@ -1798,12 +1798,12 @@
 int mpegps_init(void)
 {
 #ifdef CONFIG_MUXERS
-    av_register_output_format(&mpeg1system_mux);
-    av_register_output_format(&mpeg1vcd_mux);
-    av_register_output_format(&mpeg2vob_mux);
-    av_register_output_format(&mpeg2svcd_mux);
-    av_register_output_format(&mpeg2dvd_mux);
+    av_register_output_format(&mpeg1system_muxer);
+    av_register_output_format(&mpeg1vcd_muxer);
+    av_register_output_format(&mpeg2vob_muxer);
+    av_register_output_format(&mpeg2svcd_muxer);
+    av_register_output_format(&mpeg2dvd_muxer);
 #endif //CONFIG_MUXERS
-    av_register_input_format(&mpegps_demux);
+    av_register_input_format(&mpegps_demuxer);
     return 0;
 }